@@ -2,7 +2,10 @@
 #' @title Plot numeric basis function summation series.
 #'
 #' @param x A \code{\link{numericBasis_series}} object.
+#' @param y Ignored. Present for consistency with the generic \code{plot()} function.
+#' @param ... other parameters to be passed through to plotting functions.
 #'
+#' @importFrom utils modifyList
 #' @author Heyang Ji
 #' @export
 #' @examples
@@ -20,12 +23,29 @@
 
 setMethod("plot",
           signature(x="numericBasis_series"),
-          function(x){
+          function(x,...){
+
             t = x@numeric_basis@t_0 + x@numeric_basis@period*(0:1000/1000)
-            plot(x = t, y = numericBasisSeries2fun(x,t),
-                 xlab = "Domain",
-                 ylab = "Series value",
-                 main = "Numeric Basis Function Series")
+            y = numericBasisSeries2fun(x,t)
+
+            defaults <- list(
+              x    = t,
+              y    = y,
+              xlab = "Domain",
+              ylab = "Series value",
+              main = "Numeric Basis Function Series"
+            )
+            user_args <- list(...)
+
+            final_args <- utils::modifyList(defaults, user_args)
+
+            do.call(plot, final_args)
+
+            # t = x@numeric_basis@t_0 + x@numeric_basis@period*(0:1000/1000)
+            # plot(x = t, y = numericBasisSeries2fun(x,t),
+            #      xlab = "Domain",
+            #      ylab = "Series value",
+            #      main = "Numeric Basis Function Series",...)
           })
 # plot.numericBasis_series = function(x){
 #   t = x@numeric_basis@t_0 + x@numeric_basis@period*(0:1000/1000)
